Document title goes here

# Stallen reinigen en spuiten

Van belang is dat de spuitlans de juiste lengte heeft om rechtopstaand te werken. Een gebogen spuitlans geeft een hogere polsbelasting en wordt daarom afgeraden.

Zie www.fytostat.nl.

Date test
Effective date Deze datum bepaalt per wanneer een item zichtbaar is in de site. Day Month
Year
Separation title Statement* This is a short statement about a possible risk. Read more… Er kan gebruik worden gemaakt van rechte spuitlansen van verschillende lengte Problem description* Er kan geen gebruik worden gemaakt van rechte spuitlansen van verschillende lengte
Show 'not applicable identification' option* This is a short statement about a possible risk Yes No
Risk type
Evaluation method* This is a short statement about a possible risk Calculated Estimated
Default probability* This is a short statement about a possible risk No default Small Medium Big
Default frequency* This is a short statement about a possible risk No default Almost never Regularly Constantly
Default sevirity* This is a short statement about a possible risk No default Weak severity Significant severity High/very high severity
Default evaluation* This is a short statement about how to select a default evaluation No default Low Average High
Image

Content

Statement * This is a short statement about a possible risk. Double label test * This is a short statement about a possible risk. Problem description * This is the inverse of the statement: a short description of current (bad) situation.

Description*

Describe the risk. Include any relevant information that may be helpful for users.

Maak aan alle (nieuwe) medewerkers bekend dat gebruik gemaakt kan worden van het arbeidsomstandighedenspreekuur.

Legal and policy references.

Please enter text here

Main image

The main image will get a more prominent position in the client than the other images

Image file Image caption
Secondary images

##### Secondary image 1

Image file Image caption

##### Secondary image 2

Image file Image caption

##### Secondary image 3

Image file Image caption

- Surveys
- Documentation
- Sectors
- OiRA
- Search

### Survey versions

Survey 2010

- Current / Published January 4 2009 Preview Edit

Survey 2009

- Current December 12 2009 Preview Edit
- Published August 5 2009 Preview Edit Update
- March 18 2009 Preview Edit
- February 2 2009 Preview Edit
- January 28 2009 Preview Edit

##### Legend

- Current Version that is currently online
- Current Version you are currently reviewing

Update = This version has changes that are currently unpublished. Click the update icon to bring all the changes live

Draft

Leave retracted Published
Write a revision note.
Notify

Link to sector organisation | Disclaimer | Design by Cornae